@@ -1,10 +1,23 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
+"""
+Python-nvd3 is a Python wrapper for NVD3 graph library.
+NVD3 is an attempt to build re-usable charts and chart components
+for d3.js without taking away the power that d3.js gives you.
+
+Project location : https://github.com/areski/python-nvd3
+"""
+
 from NVD3Chart import NVD3Chart
 
 
 class linePlusBarChart(NVD3Chart):
     """
+    A linePlusBarChart Chart is a type of chart which displays information
+    as a series of data points connected by straight line segments
+    and with some series with rectangular bars with lengths proportional
+    to the values that they represent
 
     .. image:: ../_static/screenshot/linePlusBarChart.png
 
