@@ -1,10 +1,24 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
+"""
+Python-nvd3 is a Python wrapper for NVD3 graph library.
+NVD3 is an attempt to build re-usable charts and chart components
+for d3.js without taking away the power that d3.js gives you.
+
+Project location : https://github.com/areski/python-nvd3
+"""
+
 from NVD3Chart import NVD3Chart
 
 
 class lineWithFocusChart(NVD3Chart):
     """
+    A lineWithFocusChart or line graph is a type of chart which displays information
+    as a series of data points connected by straight line segments.
+    The lineWithFocusChart provide a smaller chart that act as a selector,
+    this is very useful if you want to zoom on a specific time period.
+
     .. image:: ../_static/screenshot/lineWithFocusChart.png
 
     Python example::
